
# Slot: slots


list of slot names that are applicable to a class

URI: [meta:slots](https://w3id.org/biolink/biolinkml/meta/slots)

## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>0..*</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
